@@ -21,6 +21,7 @@ import (
 	"net/http"
 	"reflect"
 	"testing"
+	"time"
 )
 
 func TestListServices(t *testing.T) {
@@ -46,7 +47,16 @@ func TestCustomIssueTrackerService(t *testing.T) {
 
 	mux.HandleFunc("/api/v4/projects/1/services/custom-issue-tracker", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
-		fmt.Fprint(w, `{"id": 1, "title": "5", "push_events": true, "properties": {"new_issue_url":"1", "issues_url": "2", "project_url": "3"}}`)
+		fmt.Fprint(w, `{
+      "id": 1,
+      "title": "5",
+      "push_events": true,
+      "properties": {
+        "new_issue_url": "1",
+        "issues_url": "2",
+        "project_url": "3"
+      }
+    }`)
 	})
 	want := &CustomIssueTrackerService{
 		Service: Service{
@@ -78,12 +88,9 @@ func TestSetCustomIssueTrackerService(t *testing.T) {
 	})
 
 	opt := &SetCustomIssueTrackerServiceOptions{
-		NewIssueURL: String("1"),
-		IssuesURL:   String("2"),
-		ProjectURL:  String("3"),
-		Description: String("4"),
-		Title:       String("5"),
-		PushEvents:  Bool(true),
+		NewIssueURL: Ptr("1"),
+		IssuesURL:   Ptr("2"),
+		ProjectURL:  Ptr("3"),
 	}
 
 	_, err := client.Services.SetCustomIssueTrackerService(1, opt)
@@ -105,6 +112,81 @@ func TestDeleteCustomIssueTrackerService(t *testing.T) {
 	}
 }
 
+func TestGetDataDogService(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/services/datadog", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{
+      "id": 1,
+      "active": true,
+      "properties": {
+        "api_url": "",
+        "datadog_env": "production",
+        "datadog_service": "gitlab",
+        "datadog_site": "datadoghq.com",
+        "datadog_tags": "country=canada\nprovince=ontario",
+        "archive_trace_events": true
+      }
+    }`)
+	})
+	want := &DataDogService{
+		Service: Service{ID: 1, Active: true},
+		Properties: &DataDogServiceProperties{
+			APIURL:             "",
+			DataDogEnv:         "production",
+			DataDogService:     "gitlab",
+			DataDogSite:        "datadoghq.com",
+			DataDogTags:        "country=canada\nprovince=ontario",
+			ArchiveTraceEvents: true,
+		},
+	}
+
+	service, _, err := client.Services.GetDataDogService(1)
+	if err != nil {
+		t.Fatalf("Services.GetDataDogService returns an error: %v", err)
+	}
+	if !reflect.DeepEqual(want, service) {
+		t.Errorf("Services.GetDataDogService returned %+v, want %+v", service, want)
+	}
+}
+
+func TestSetDataDogService(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/services/datadog", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPut)
+	})
+
+	opt := &SetDataDogServiceOptions{
+		APIKey:             String("secret"),
+		APIURL:             String("https://some-api.com"),
+		DataDogEnv:         String("sandbox"),
+		DataDogService:     String("source-code"),
+		DataDogSite:        String("datadoghq.eu"),
+		DataDogTags:        String("country=france"),
+		ArchiveTraceEvents: Bool(false),
+	}
+
+	_, err := client.Services.SetDataDogService(1, opt)
+	if err != nil {
+		t.Fatalf("Services.SetDataDogService returns an error: %v", err)
+	}
+}
+
+func TestDeleteDataDogService(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/services/datadog", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodDelete)
+	})
+
+	_, err := client.Services.DeleteDataDogService(1)
+	if err != nil {
+		t.Fatalf("Services.DeleteDataDogService returns an error: %v", err)
+	}
+}
+
 func TestGetDiscordService(t *testing.T) {
 	mux, client := setup(t)
 
@@ -131,7 +213,7 @@ func TestSetDiscordService(t *testing.T) {
 	})
 
 	opt := &SetDiscordServiceOptions{
-		WebHook: String("webhook_uri"),
+		WebHook: Ptr("webhook_uri"),
 	}
 
 	_, err := client.Services.SetDiscordService(1, opt)
@@ -178,7 +260,7 @@ func TestSetDroneCIService(t *testing.T) {
 		testMethod(t, r, http.MethodPut)
 	})
 
-	opt := &SetDroneCIServiceOptions{String("t"), String("u"), Bool(true)}
+	opt := &SetDroneCIServiceOptions{Ptr("token"), Ptr("drone-url"), Ptr(true), nil, nil, nil}
 
 	_, err := client.Services.SetDroneCIService(1, opt)
 	if err != nil {
@@ -224,7 +306,7 @@ func TestSetEmailsOnPushService(t *testing.T) {
 		testMethod(t, r, http.MethodPut)
 	})
 
-	opt := &SetEmailsOnPushServiceOptions{String("t"), Bool(true), Bool(true), Bool(true), Bool(true), String("t")}
+	opt := &SetEmailsOnPushServiceOptions{Ptr("t"), Ptr(true), Ptr(true), Ptr(true), Ptr(true), Ptr("t")}
 
 	_, err := client.Services.SetEmailsOnPushService(1, opt)
 	if err != nil {
@@ -245,6 +327,52 @@ func TestDeleteEmailsOnPushService(t *testing.T) {
 	}
 }
 
+func TestGetSlackApplication(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/integrations/gitlab-slack-application", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{"id":1}`)
+	})
+	want := &SlackApplication{Service: Service{ID: 1}}
+
+	service, _, err := client.Services.GetSlackApplication(1)
+	if err != nil {
+		t.Fatalf("Services.GetSlackApplication returns an error: %v", err)
+	}
+	if !reflect.DeepEqual(want, service) {
+		t.Errorf("Services.GetSlackApplication returned %+v, want %+v", service, want)
+	}
+}
+
+func TestSetSlackApplication(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/integrations/gitlab-slack-application", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPut)
+	})
+
+	opt := &SetSlackApplicationOptions{Channel: Ptr("#channel1"), NoteEvents: Ptr(true), AlertEvents: Ptr(true)}
+
+	_, err := client.Services.SetSlackApplication(1, opt)
+	if err != nil {
+		t.Fatalf("Services.SetSlackApplication returns an error: %v", err)
+	}
+}
+
+func TestDisableSlackApplication(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/integrations/gitlab-slack-application", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodDelete)
+	})
+
+	_, err := client.Services.DisableSlackApplication(1)
+	if err != nil {
+		t.Fatalf("Services.DisableSlackApplication returns an error: %v", err)
+	}
+}
+
 func TestGetJiraService(t *testing.T) {
 	mux, client := setup(t)
 
@@ -313,16 +441,16 @@ func TestSetJiraService(t *testing.T) {
 	})
 
 	opt := &SetJiraServiceOptions{
-		URL:                   String("asd"),
-		APIURL:                String("asd"),
-		ProjectKey:            String("as"),
-		Username:              String("aas"),
-		Password:              String("asd"),
-		Active:                Bool(true),
-		JiraIssueTransitionID: String("2,3"),
-		CommitEvents:          Bool(true),
-		CommentOnEventEnabled: Bool(true),
-		MergeRequestsEvents:   Bool(true),
+		URL:                   Ptr("asd"),
+		APIURL:                Ptr("asd"),
+		ProjectKey:            Ptr("as"),
+		Username:              Ptr("aas"),
+		Password:              Ptr("asd"),
+		Active:                Ptr(true),
+		JiraIssueTransitionID: Ptr("2,3"),
+		CommitEvents:          Ptr(true),
+		CommentOnEventEnabled: Ptr(true),
+		MergeRequestsEvents:   Ptr(true),
 	}
 
 	_, err := client.Services.SetJiraService(1, opt)
@@ -370,9 +498,9 @@ func TestSetMattermostService(t *testing.T) {
 	})
 
 	opt := &SetMattermostServiceOptions{
-		WebHook:  String("webhook_uri"),
-		Username: String("username"),
-		Channel:  String("#development"),
+		WebHook:  Ptr("webhook_uri"),
+		Username: Ptr("username"),
+		Channel:  Ptr("#development"),
 	}
 
 	_, err := client.Services.SetMattermostService(1, opt)
@@ -394,6 +522,55 @@ func TestDeleteMattermostService(t *testing.T) {
 	}
 }
 
+func TestGetMattermostSlashCommandsService(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/services/mattermost-slash-commands", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{"id":1}`)
+	})
+	want := &MattermostSlashCommandsService{Service: Service{ID: 1}}
+
+	service, _, err := client.Services.GetMattermostSlashCommandsService(1)
+	if err != nil {
+		t.Fatalf("Services.mattermost-slash-commands returns an error: %v", err)
+	}
+	if !reflect.DeepEqual(want, service) {
+		t.Errorf("Services.mattermost-slash-commands returned %+v, want %+v", service, want)
+	}
+}
+
+func TestSetMattermostSlashCommandsService(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/services/mattermost-slash-commands", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPut)
+	})
+
+	opt := &SetMattermostSlashCommandsServiceOptions{
+		Token:    Ptr("token"),
+		Username: Ptr("username"),
+	}
+
+	_, err := client.Services.SetMattermostSlashCommandsService(1, opt)
+	if err != nil {
+		t.Fatalf("Services.SetMattermostSlashCommandsService returns an error: %v", err)
+	}
+}
+
+func TestDeleteMattermostSlashCommandsService(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/services/mattermost-slash-commands", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodDelete)
+	})
+
+	_, err := client.Services.DeleteMattermostSlashCommandsService(1)
+	if err != nil {
+		t.Fatalf("Services.DeleteMattermostSlashCommandsService returns an error: %v", err)
+	}
+}
+
 func TestGetPipelinesEmailService(t *testing.T) {
 	mux, client := setup(t)
 
@@ -420,9 +597,9 @@ func TestSetPipelinesEmailService(t *testing.T) {
 	})
 
 	opt := &SetPipelinesEmailServiceOptions{
-		Recipients:                String("test@email.com"),
-		NotifyOnlyBrokenPipelines: Bool(true),
-		NotifyOnlyDefaultBranch:   Bool(false),
+		Recipients:                Ptr("test@email.com"),
+		NotifyOnlyBrokenPipelines: Ptr(true),
+		NotifyOnlyDefaultBranch:   Ptr(false),
 		AddPusher:                 nil,
 		BranchesToBeNotified:      nil,
 		PipelineEvents:            nil,
@@ -472,7 +649,7 @@ func TestSetPrometheusService(t *testing.T) {
 		testMethod(t, r, http.MethodPut)
 	})
 
-	opt := &SetPrometheusServiceOptions{String("t"), String("u"), String("a")}
+	opt := &SetPrometheusServiceOptions{Ptr("t"), Ptr("u"), Ptr("a")}
 
 	_, err := client.Services.SetPrometheusService(1, opt)
 	if err != nil {
@@ -519,9 +696,9 @@ func TestSetSlackService(t *testing.T) {
 	})
 
 	opt := &SetSlackServiceOptions{
-		WebHook:  String("webhook_uri"),
-		Username: String("username"),
-		Channel:  String("#development"),
+		WebHook:  Ptr("webhook_uri"),
+		Username: Ptr("username"),
+		Channel:  Ptr("#development"),
 	}
 
 	_, err := client.Services.SetSlackService(1, opt)
@@ -543,57 +720,6 @@ func TestDeleteSlackService(t *testing.T) {
 	}
 }
 
-func TestGetYouTrackService(t *testing.T) {
-	mux, client := setup(t)
-
-	mux.HandleFunc("/api/v4/projects/1/services/youtrack", func(w http.ResponseWriter, r *http.Request) {
-		testMethod(t, r, http.MethodGet)
-		fmt.Fprint(w, `{"id":1}`)
-	})
-	want := &YouTrackService{Service: Service{ID: 1}}
-
-	service, _, err := client.Services.GetYouTrackService(1)
-	if err != nil {
-		t.Fatalf("Services.GetYouTrackService returns an error: %v", err)
-	}
-	if !reflect.DeepEqual(want, service) {
-		t.Errorf("Services.GetYouTrackService returned %+v, want %+v", service, want)
-	}
-}
-
-func TestSetYouTrackService(t *testing.T) {
-	mux, client := setup(t)
-
-	mux.HandleFunc("/api/v4/projects/1/services/youtrack", func(w http.ResponseWriter, r *http.Request) {
-		testMethod(t, r, http.MethodPut)
-	})
-
-	opt := &SetYouTrackServiceOptions{
-		IssuesURL:   String("https://example.org/youtrack/issue/:id"),
-		ProjectURL:  String("https://example.org/youtrack/projects/1"),
-		Description: String("description"),
-		PushEvents:  Bool(true),
-	}
-
-	_, err := client.Services.SetYouTrackService(1, opt)
-	if err != nil {
-		t.Fatalf("Services.SetYouTrackService returns an error: %v", err)
-	}
-}
-
-func TestDeleteYouTrackService(t *testing.T) {
-	mux, client := setup(t)
-
-	mux.HandleFunc("/api/v4/projects/1/services/youtrack", func(w http.ResponseWriter, r *http.Request) {
-		testMethod(t, r, http.MethodDelete)
-	})
-
-	_, err := client.Services.DeleteYouTrackService(1)
-	if err != nil {
-		t.Fatalf("Services.DeleteYouTrackService returns an error: %v", err)
-	}
-}
-
 func TestGetSlackSlashCommandsService(t *testing.T) {
 	mux, client := setup(t)
 
@@ -620,7 +746,7 @@ func TestSetSlackSlashCommandsService(t *testing.T) {
 	})
 
 	opt := &SetSlackSlashCommandsServiceOptions{
-		Token: String("token"),
+		Token: Ptr("token"),
 	}
 
 	_, err := client.Services.SetSlackSlashCommandsService(1, opt)
@@ -642,51 +768,174 @@ func TestDeleteSlackSlashCommandsService(t *testing.T) {
 	}
 }
 
-func TestGetMattermostSlashCommandsService(t *testing.T) {
+func TestGetTelegramService(t *testing.T) {
 	mux, client := setup(t)
 
-	mux.HandleFunc("/api/v4/projects/1/services/mattermost-slash-commands", func(w http.ResponseWriter, r *http.Request) {
+	mux.HandleFunc("/api/v4/projects/1/services/telegram", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
-		fmt.Fprint(w, `{"id":1}`)
+		fmt.Fprint(w, `
+			{
+			  "id": 1,
+			  "title": "Telegram",
+			  "slug": "telegram",
+			  "created_at": "2023-12-16T20:21:03.117Z",
+			  "updated_at": "2023-12-16T20:22:19.140Z",
+			  "active": true,
+			  "commit_events": true,
+			  "push_events": false,
+			  "issues_events": false,
+			  "incident_events": false,
+			  "alert_events": true,
+			  "confidential_issues_events": false,
+			  "merge_requests_events": false,
+			  "tag_push_events": false,
+			  "deployment_events": false,
+			  "note_events": false,
+			  "confidential_note_events": false,
+			  "pipeline_events": true,
+			  "wiki_page_events": false,
+			  "job_events": true,
+			  "comment_on_event_enabled": true,
+			  "vulnerability_events": false,
+			  "properties": {
+				"room": "-1000000000000",
+				"notify_only_broken_pipelines": false,
+				"branches_to_be_notified": "all"
+			  }
+			}
+		`)
 	})
-	want := &MattermostSlashCommandsService{Service: Service{ID: 1}}
+	wantCreatedAt, _ := time.Parse(time.RFC3339, "2023-12-16T20:21:03.117Z")
+	wantUpdatedAt, _ := time.Parse(time.RFC3339, "2023-12-16T20:22:19.140Z")
+	want := &TelegramService{
+		Service: Service{
+			ID:                       1,
+			Title:                    "Telegram",
+			Slug:                     "telegram",
+			CreatedAt:                &wantCreatedAt,
+			UpdatedAt:                &wantUpdatedAt,
+			Active:                   true,
+			CommitEvents:             true,
+			PushEvents:               false,
+			IssuesEvents:             false,
+			AlertEvents:              true,
+			ConfidentialIssuesEvents: false,
+			MergeRequestsEvents:      false,
+			TagPushEvents:            false,
+			DeploymentEvents:         false,
+			NoteEvents:               false,
+			ConfidentialNoteEvents:   false,
+			PipelineEvents:           true,
+			WikiPageEvents:           false,
+			JobEvents:                true,
+			CommentOnEventEnabled:    true,
+			VulnerabilityEvents:      false,
+		},
+		Properties: &TelegramServiceProperties{
+			Room:                      "-1000000000000",
+			NotifyOnlyBrokenPipelines: false,
+			BranchesToBeNotified:      "all",
+		},
+	}
 
-	service, _, err := client.Services.GetMattermostSlashCommandsService(1)
+	service, _, err := client.Services.GetTelegramService(1)
 	if err != nil {
-		t.Fatalf("Services.mattermost-slash-commands returns an error: %v", err)
+		t.Fatalf("Services.GetTelegramService returns an error: %v", err)
 	}
 	if !reflect.DeepEqual(want, service) {
-		t.Errorf("Services.mattermost-slash-commands returned %+v, want %+v", service, want)
+		t.Errorf("Services.GetTelegramService returned %+v, want %+v", service, want)
 	}
 }
 
-func TestSetMattermostSlashCommandsService(t *testing.T) {
+func TestSetTelegramService(t *testing.T) {
 	mux, client := setup(t)
 
-	mux.HandleFunc("/api/v4/projects/1/services/mattermost-slash-commands", func(w http.ResponseWriter, r *http.Request) {
+	mux.HandleFunc("/api/v4/projects/1/services/telegram", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPut)
 	})
 
-	opt := &SetMattermostSlashCommandsServiceOptions{
-		Token:    String("token"),
-		Username: String("username"),
+	opt := &SetTelegramServiceOptions{
+		Token:                     Ptr("token"),
+		Room:                      Ptr("-1000"),
+		NotifyOnlyBrokenPipelines: Ptr(true),
+		BranchesToBeNotified:      Ptr("all"),
+		PushEvents:                Ptr(true),
+		IssuesEvents:              Ptr(true),
+		ConfidentialIssuesEvents:  Ptr(true),
+		MergeRequestsEvents:       Ptr(true),
+		TagPushEvents:             Ptr(true),
+		NoteEvents:                Ptr(true),
+		ConfidentialNoteEvents:    Ptr(true),
+		PipelineEvents:            Ptr(true),
+		WikiPageEvents:            Ptr(true),
 	}
 
-	_, err := client.Services.SetMattermostSlashCommandsService(1, opt)
+	_, err := client.Services.SetTelegramService(1, opt)
 	if err != nil {
-		t.Fatalf("Services.SetMattermostSlashCommandsService returns an error: %v", err)
+		t.Fatalf("Services.SetTelegramService returns an error: %v", err)
 	}
 }
 
-func TestDeleteMattermostSlashCommandsService(t *testing.T) {
+func TestDeleteTelegramService(t *testing.T) {
 	mux, client := setup(t)
 
-	mux.HandleFunc("/api/v4/projects/1/services/mattermost-slash-commands", func(w http.ResponseWriter, r *http.Request) {
+	mux.HandleFunc("/api/v4/projects/1/services/telegram", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodDelete)
 	})
 
-	_, err := client.Services.DeleteMattermostSlashCommandsService(1)
+	_, err := client.Services.DeleteTelegramService(1)
 	if err != nil {
-		t.Fatalf("Services.DeleteMattermostSlashCommandsService returns an error: %v", err)
+		t.Fatalf("Services.DeleteTelegramService returns an error: %v", err)
+	}
+}
+
+func TestGetYouTrackService(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/services/youtrack", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{"id":1}`)
+	})
+	want := &YouTrackService{Service: Service{ID: 1}}
+
+	service, _, err := client.Services.GetYouTrackService(1)
+	if err != nil {
+		t.Fatalf("Services.GetYouTrackService returns an error: %v", err)
+	}
+	if !reflect.DeepEqual(want, service) {
+		t.Errorf("Services.GetYouTrackService returned %+v, want %+v", service, want)
+	}
+}
+
+func TestSetYouTrackService(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/services/youtrack", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPut)
+	})
+
+	opt := &SetYouTrackServiceOptions{
+		IssuesURL:   Ptr("https://example.org/youtrack/issue/:id"),
+		ProjectURL:  Ptr("https://example.org/youtrack/projects/1"),
+		Description: Ptr("description"),
+		PushEvents:  Ptr(true),
+	}
+
+	_, err := client.Services.SetYouTrackService(1, opt)
+	if err != nil {
+		t.Fatalf("Services.SetYouTrackService returns an error: %v", err)
+	}
+}
+
+func TestDeleteYouTrackService(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/services/youtrack", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodDelete)
+	})
+
+	_, err := client.Services.DeleteYouTrackService(1)
+	if err != nil {
+		t.Fatalf("Services.DeleteYouTrackService returns an error: %v", err)
 	}
 }
